[PATCH 1 of 5] Avoid "file name", spell filename as one word or rewrite phrase

timeless timeless at gmail.com
Fri Jun 5 10:02:47 UTC 2009


# HG changeset patch
# User timeless <timeless at gmail.com>
# Date 1244202611 -7200
# Node ID 7d1cbb86d3a13bb70fe4cbbf17fa8517f2e5db81
# Parent  b5e9ed63913b2d953eb7f6fd704b5e356fa53642
generally replace file name with filename

diff --git a/hgext/mq.py b/hgext/mq.py
--- a/hgext/mq.py
+++ b/hgext/mq.py
@@ -503,7 +503,7 @@ class queue:

     def patch(self, repo, patchfile):
         '''Apply patchfile  to the working directory.
-        patchfile: file name of patch'''
+        patchfile: name of patch file'''
         files = {}
         try:
             fuzz = patch.patch(patchfile, self.ui, strip=1, cwd=repo.root,
@@ -2541,7 +2541,7 @@ cmdtable = {
     "^qimport":
         (qimport,
          [('e', 'existing', None, _('import file in patch directory')),
-          ('n', 'name', '', _('patch file name')),
+          ('n', 'name', '', _('name of patch file')),
           ('f', 'force', None, _('overwrite existing files')),
           ('r', 'rev', [], _('place existing revisions under mq control')),
           ('g', 'git', None, _('use git extended diff format')),
diff --git a/hgext/patchbomb.py b/hgext/patchbomb.py
--- a/hgext/patchbomb.py
+++ b/hgext/patchbomb.py
@@ -148,7 +148,7 @@ def makepatch(ui, repo, patch, opts, _ch
             msg.attach(mail.mimeencode(ui, body, _charsets, opts.get('test')))
         p = mail.mimetextpatch('\n'.join(patch), 'x-patch', opts.get('test'))
         binnode = bin(node)
-        # if node is mq patch, it will have patch file name as tag
+        # if node is mq patch, it will have the patch file's name as a tag
         if not patchname:
             patchtags = [t for t in repo.nodetags(binnode)
                          if t.endswith('.patch') or t.endswith('.diff')]
@@ -490,7 +490,7 @@ cmdtable = {
           ('b', 'bundle', None,
            _('send changes not in target as a binary bundle')),
           ('', 'bundlename', 'bundle',
-           _('file name of the bundle attachment')),
+           _('name of the bundle attachment file')),
           ('r', 'rev', [], _('a revision to send')),
           ('', 'force', None,
            _('run even when remote repository is unrelated '
diff --git a/hgext/purge.py b/hgext/purge.py
--- a/hgext/purge.py
+++ b/hgext/purge.py
@@ -102,7 +102,7 @@ cmdtable = {
         (purge,
          [('a', 'abort-on-err', None, _('abort if an error occurs')),
           ('',  'all', None, _('purge ignored files too')),
-          ('p', 'print', None, _('print the file names instead of
deleting them')),
+          ('p', 'print', None, _('print filenames instead of deleting them')),
           ('0', 'print0', None, _('end filenames with NUL, for use with xargs'
                                   ' (implies -p/--print)')),
          ] + commands.walkopts,
diff --git a/mercurial/cmdutil.py b/mercurial/cmdutil.py
--- a/mercurial/cmdutil.py
+++ b/mercurial/cmdutil.py
@@ -217,7 +217,7 @@ def make_filename(repo, pat, node,
             i += 1
         return ''.join(newname)
     except KeyError, inst:
-        raise util.Abort(_("invalid format spec '%%%s' in output file name") %
+        raise util.Abort(_("invalid format spec '%%%s' in output filename") %
                          inst.args[0])

 def make_file(repo, pat, node=None,
@@ -1005,7 +1005,7 @@ def walkchangerevs(ui, repo, pats, chang
     positive if walking forwards through revs, last rev in the
     sequence iterated over - use to reset state for the current window

-    "add", rev, fns: out-of-order traversal of the given file names
+    "add", rev, fns: out-of-order traversal of the given filenames
     fns, which changed during revision rev - use to gather data for
     possible display

@@ -1096,7 +1096,7 @@ def walkchangerevs(ui, repo, pats, chang
     if slowpath:
         if follow:
             raise util.Abort(_('can only follow copies/renames for explicit '
-                               'file names'))
+                               'filenames'))

         # The slow path checks files modified in every changeset.
         def changerevgen():
diff --git a/mercurial/hgweb/common.py b/mercurial/hgweb/common.py
--- a/mercurial/hgweb/common.py
+++ b/mercurial/hgweb/common.py
@@ -71,7 +71,7 @@ def staticfile(directory, fname, req):
         req.respond(HTTP_OK, ct, length = os.path.getsize(path))
         return file(path, 'rb').read()
     except TypeError:
-        raise ErrorResponse(HTTP_SERVER_ERROR, 'illegal file name')
+        raise ErrorResponse(HTTP_SERVER_ERROR, 'illegal filename')
     except OSError, err:
         if err.errno == errno.ENOENT:
             raise ErrorResponse(HTTP_NOT_FOUND)
diff --git a/mercurial/match.py b/mercurial/match.py
--- a/mercurial/match.py
+++ b/mercurial/match.py
@@ -1,4 +1,4 @@
-# match.py - file name matching
+# match.py - filename matching
 #
 #  Copyright 2008, 2009 Matt Mackall <mpm at selenic.com> and others
 #
diff --git a/mercurial/patch.py b/mercurial/patch.py
--- a/mercurial/patch.py
+++ b/mercurial/patch.py
@@ -1350,7 +1350,7 @@ def diffstatdata(lines):
             if line.startswith('diff --git'):
                 filename = gitre.search(line).group(1)
             else:
-                # format: "diff -r ... -r ... file name"
+                # format: "diff -r ... -r ... filename"
                 filename = line.split(None, 5)[-1]
         elif line.startswith('+') and not line.startswith('+++'):
             adds += 1
diff --git a/mercurial/posix.py b/mercurial/posix.py
--- a/mercurial/posix.py
+++ b/mercurial/posix.py
@@ -46,7 +46,7 @@ def user_rcpath():
     return [os.path.expanduser('~/.hgrc')]

 def parse_patch_output(output_line):
-    """parses the output produced by patch and returns the file name"""
+    """parses the output produced by patch and returns the filename"""
     pf = output_line[14:]
     if os.sys.platform == 'OpenVMS':
         if pf[0] == '`':
diff --git a/mercurial/streamclone.py b/mercurial/streamclone.py
--- a/mercurial/streamclone.py
+++ b/mercurial/streamclone.py
@@ -28,7 +28,7 @@ class StreamException(Exception):
 #
 # then for each file:
 #
-#   server writes out line that says file name, how many bytes in
+#   server writes out line that says filename, how many bytes in
 #   file.  separator is ascii nul, byte count is string.
 #
 #   server writes out raw file data.
diff --git a/mercurial/windows.py b/mercurial/windows.py
--- a/mercurial/windows.py
+++ b/mercurial/windows.py
@@ -91,7 +91,7 @@ def user_rcpath():
     return path

 def parse_patch_output(output_line):
-    """parses the output produced by patch and returns the file name"""
+    """parses the output produced by patch and returns the filename"""
     pf = output_line[14:]
     if pf[0] == '`':
         pf = pf[1:-1] # Remove the quotes



More information about the Mercurial-devel mailing list
diff --git a/mercurial/commands.py b/mercurial/commands.py
--- a/mercurial/commands.py
+++ b/mercurial/commands.py
@@ -88,7 +88,7 @@ def annotate(ui, repo, *pats, **opts):
     getdate = util.cachefunc(lambda x: datefunc(x[0].date()))

     if not pats:
-        raise util.Abort(_('at least one file name or pattern required'))
+        raise util.Abort(_('at least one filename or pattern is required'))

     opmap = [('user', lambda x: ui.shortuser(x[0].user())),
              ('number', lambda x: str(x[0].rev())),
@@ -630,7 +630,7 @@ def commit(ui, repo, *pats, **opts):
     will be committed.

     If you are committing the result of a merge, do not provide any
-    file names or -I/-X filters.
+    filenames or -I/-X filters.

     If no commit message is specified, the configured editor is
     started to prompt you for a message.
@@ -1894,8 +1894,8 @@ def log(ui, repo, *pats, **opts):
     project.

     File history is shown without following rename or copy history of
     files. Use -f/--follow with a file name to follow history across
     renames and copies. --follow without a file name will only show
     ancestors or descendants of the starting revision. --follow-first
     only follows the first parent of merge revisions.

@@ -2151,7 +2151,7 @@ def parents(ui, repo, file_=None, **opts
     if file_:
         m = cmdutil.match(repo, (file_,), opts)
         if m.anypats() or len(m.files()) != 1:
-            raise util.Abort(_('can only specify an explicit file name'))
+            raise util.Abort(_('can only specify an explicit filename'))
         file_ = m.files()[0]
         filenodes = []
         for cp in ctx.parents():
@@ -1894,8 +1894,8 @@ def log(ui, repo, *pats, **opts):

     File history is shown without following rename or copy history of
-    files. Use -f/--follow with a file name to follow history across
-    renames and copies. --follow without a file name will only show
+    files. Use -f/--follow with a filename to follow history across
+    renames and copies. --follow without a filename will only show
     ancestors or descendants of the starting revision. --follow-first
     only follows the first parent of merge revisions.